dateModifiedGmt property

DateTime? dateModifiedGmt
getter/setter pair

Date and time when the order was last modified (GMT)

This timestamp reflects when the order was last updated in GMT/UTC timezone.

Implementation

DateTime? dateModifiedGmt;