lineItems property

List<WooLineItem>? lineItems
getter/setter pair

Line items being refunded

The specific products and quantities that are being refunded. Each line item includes the product details and refund amounts.

Implementation

List<WooLineItem>? lineItems;