metaData property
Custom refund metadata
Additional custom data associated with the refund, including administrative notes and custom fields.
Implementation
List<WooMetaData>? metaData;
Custom refund metadata
Additional custom data associated with the refund, including administrative notes and custom fields.
List<WooMetaData>? metaData;