create property

List<WooProductReview>? create
final

List of created reviews

Contains the reviews that were successfully created, each with a server-assigned ID and all other properties as returned by the API.

Implementation

final List<WooProductReview>? create;