WooProductReviewTotalReport class

Represents a product review total report with basic information.

Brief description of the model's purpose and usage.

Constructors

WooProductReviewTotalReport({String? slug, String? name, String? total})
Creates a new WooProductReviewTotalReport instance.
WooProductReviewTotalReport.fake()
factory
WooProductReviewTotalReport.fromJson(Map<String, dynamic> json)
Creates a WooProductReviewTotalReport instance from JSON data.

Properties

hashCode int
The hash code for this object.
no setteroverride
name String?
Review type name.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slug String?
An alphanumeric identifier for the resource.
getter/setter pair
total String?
Amount of reviews.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns a string representation of the WooProductReviewTotalReport instance.
override

Operators

operator ==(Object other) bool
The equality operator.
override