WooProductShippingClass class

Represents a product shipping class with metadata.

Brief description of the model's purpose and usage for product shipping classes.

Constructors

WooProductShippingClass(int? id, String? name, String? slug, String? description, int? count)
Creates a new WooProductShippingClass instance.
WooProductShippingClass.fake([int? id])
Creates a fake WooProductShippingClass instance for testing purposes.
factory
WooProductShippingClass.fromJson(Map<String, dynamic> json)
Creates a WooProductShippingClass instance from JSON data.

Properties

count int?
Number of published products for the resource.
final
description String?
HTML description of the resource.
final
hashCode int
The hash code for this object.
no setterinherited
id int?
Unique identifier for the resource.
final
name String?
Shipping class name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slug String?
An alphanumeric identifier for the resource unique to its type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the WooProductShippingClass instance to JSON format.
toString() String
Returns a string representation of the WooProductShippingClass instance.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited