WooTaxClass class

Represents a tax class with basic information.

Brief description of the model's purpose and usage.

Constructors

WooTaxClass({String? slug, String? name})
Creates a new WooTaxClass instance.
WooTaxClass.fake([int? id])
factory
WooTaxClass.fromJson(Map<String, dynamic> json)
Creates a WooTaxClass instance from JSON data.

Properties

hashCode int
The hash code for this object.
no setteroverride
name String?
Tax class name.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slug String?
Unique identifier for the resource.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
Returns a string representation of the WooTaxClass instance.
override

Operators

operator ==(Object other) bool
The equality operator.
override