name property
Human-readable name for the webhook
This name helps you identify the webhook in the WooCommerce admin panel and in your application. It should be descriptive of the webhook's purpose.
Implementation
final String? name;
Human-readable name for the webhook
This name helps you identify the webhook in the WooCommerce admin panel and in your application. It should be descriptive of the webhook's purpose.
final String? name;