lineItems property
Line items being refunded
The specific products and quantities that are being refunded. Each line item includes the product details and refund amounts.
Implementation
List<WooLineItem>? lineItems;
Line items being refunded
The specific products and quantities that are being refunded. Each line item includes the product details and refund amounts.
List<WooLineItem>? lineItems;