create property
List of created reviews
Contains the reviews that were successfully created, each with a server-assigned ID and all other properties as returned by the API.
Implementation
final List<WooProductReview>? create;
List of created reviews
Contains the reviews that were successfully created, each with a server-assigned ID and all other properties as returned by the API.
final List<WooProductReview>? create;